==> openshift-model-operatorhub-5.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionConfigFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.ResourceRequirementsBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluent;
import io.fabric8.kubernetes.api.model.EnvVar;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.EnvFromSource;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.VolumeMount;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

 /**
  * Generated
  */
public interface SubscriptionConfigFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A setToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A addToEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToEnv(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public A removeFromEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromEnv(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public java.util.List<io.fabric8.kubernetes.api.model.EnvVar> getEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getEnv(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.EnvVar getFirstEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getLastEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public java.lang.Boolean hasMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public A withEnv(java.util.List<io.fabric8.kubernetes.api.model.EnvVar> env);
  public A withEnv(io.fabric8.kubernetes.api.model.EnvVar... env);
  public java.lang.Boolean hasEnv();
  public A addToEnvFrom(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvFromSource item);
  public A setToEnvFrom(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvFromSource item);
  public A addToEnvFrom(io.fabric8.kubernetes.api.model.EnvFromSource... items);
  public A addAllToEnvFrom(java.util.Collection<io.fabric8.kubernetes.api.model.EnvFromSource> items);
  public A removeFromEnvFrom(io.fabric8.kubernetes.api.model.EnvFromSource... items);
  public A removeAllFromEnvFrom(java.util.Collection<io.fabric8.kubernetes.api.model.EnvFromSource> items);
  public java.util.List<io.fabric8.kubernetes.api.model.EnvFromSource> getEnvFrom();
  public io.fabric8.kubernetes.api.model.EnvFromSource getEnvFrom(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.EnvFromSource getFirstEnvFrom();
  public io.fabric8.kubernetes.api.model.EnvFromSource getLastEnvFrom();
  public io.fabric8.kubernetes.api.model.EnvFromSource getMatchingEnvFrom(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvFromSource> predicate);
  public java.lang.Boolean hasMatchingEnvFrom(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvFromSource> predicate);
  public A withEnvFrom(java.util.List<io.fabric8.kubernetes.api.model.EnvFromSource> envFrom);
  public A withEnvFrom(io.fabric8.kubernetes.api.model.EnvFromSource... envFrom);
  public java.lang.Boolean hasEnvFrom();
  public A addToNodeSelector(java.lang.String key,java.lang.String value);
  public A addToNodeSelector(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromNodeSelector(java.lang.String key);
  public A removeFromNodeSelector(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getNodeSelector();
  public <K,V>A withNodeSelector(java.util.Map<java.lang.String,java.lang.String> nodeSelector);
  public java.lang.Boolean hasNodeSelector();
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ResourceRequirements getResources();
  public io.fabric8.kubernetes.api.model.ResourceRequirements buildResources();
  public A withResources(io.fabric8.kubernetes.api.model.ResourceRequirements resources);
  public java.lang.Boolean hasResources();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> withNewResources();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> withNewResourcesLike(io.fabric8.kubernetes.api.model.ResourceRequirements item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> editResources();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> editOrNewResources();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> editOrNewResourcesLike(io.fabric8.kubernetes.api.model.ResourceRequirements item);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector();
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector);
  public java.lang.Boolean hasSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> withNewSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> editSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> editOrNewSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public A addToTolerations(java.lang.Integer index,io.fabric8.kubernetes.api.model.Toleration item);
  public A setToTolerations(java.lang.Integer index,io.fabric8.kubernetes.api.model.Toleration item);
  public A addToTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A addAllToTolerations(java.util.Collection<io.fabric8.kubernetes.api.model.Toleration> items);
  public A removeFromTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A removeAllFromTolerations(java.util.Collection<io.fabric8.kubernetes.api.model.Toleration> items);
  public java.util.List<io.fabric8.kubernetes.api.model.Toleration> getTolerations();
  public io.fabric8.kubernetes.api.model.Toleration getToleration(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.Toleration getFirstToleration();
  public io.fabric8.kubernetes.api.model.Toleration getLastToleration();
  public io.fabric8.kubernetes.api.model.Toleration getMatchingToleration(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Toleration> predicate);
  public java.lang.Boolean hasMatchingToleration(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Toleration> predicate);
  public A withTolerations(java.util.List<io.fabric8.kubernetes.api.model.Toleration> tolerations);
  public A withTolerations(io.fabric8.kubernetes.api.model.Toleration... tolerations);
  public java.lang.Boolean hasTolerations();
  public A addNewToleration(java.lang.String effect,java.lang.String key,java.lang.String operator,java.lang.Long tolerationSeconds,java.lang.String value);
  public A addToVolumeMounts(java.lang.Integer index,io.fabric8.kubernetes.api.model.VolumeMount item);
  public A setToVolumeMounts(java.lang.Integer index,io.fabric8.kubernetes.api.model.VolumeMount item);
  public A addToVolumeMounts(io.fabric8.kubernetes.api.model.VolumeMount... items);
  public A addAllToVolumeMounts(java.util.Collection<io.fabric8.kubernetes.api.model.VolumeMount> items);
  public A removeFromVolumeMounts(io.fabric8.kubernetes.api.model.VolumeMount... items);
  public A removeAllFromVolumeMounts(java.util.Collection<io.fabric8.kubernetes.api.model.VolumeMount> items);
  public java.util.List<io.fabric8.kubernetes.api.model.VolumeMount> getVolumeMounts();
  public io.fabric8.kubernetes.api.model.VolumeMount getVolumeMount(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.VolumeMount getFirstVolumeMount();
  public io.fabric8.kubernetes.api.model.VolumeMount getLastVolumeMount();
  public io.fabric8.kubernetes.api.model.VolumeMount getMatchingVolumeMount(java.util.function.Predicate<io.fabric8.kubernetes.api.model.VolumeMount> predicate);
  public java.lang.Boolean hasMatchingVolumeMount(java.util.function.Predicate<io.fabric8.kubernetes.api.model.VolumeMount> predicate);
  public A withVolumeMounts(java.util.List<io.fabric8.kubernetes.api.model.VolumeMount> volumeMounts);
  public A withVolumeMounts(io.fabric8.kubernetes.api.model.VolumeMount... volumeMounts);
  public java.lang.Boolean hasVolumeMounts();
  public A addToVolumes(java.lang.Integer index,io.fabric8.kubernetes.api.model.Volume item);
  public A setToVolumes(java.lang.Integer index,io.fabric8.kubernetes.api.model.Volume item);
  public A addToVolumes(io.fabric8.kubernetes.api.model.Volume... items);
  public A addAllToVolumes(java.util.Collection<io.fabric8.kubernetes.api.model.Volume> items);
  public A removeFromVolumes(io.fabric8.kubernetes.api.model.Volume... items);
  public A removeAllFromVolumes(java.util.Collection<io.fabric8.kubernetes.api.model.Volume> items);
  public java.util.List<io.fabric8.kubernetes.api.model.Volume> getVolumes();
  public io.fabric8.kubernetes.api.model.Volume getVolume(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.Volume getFirstVolume();
  public io.fabric8.kubernetes.api.model.Volume getLastVolume();
  public io.fabric8.kubernetes.api.model.Volume getMatchingVolume(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Volume> predicate);
  public java.lang.Boolean hasMatchingVolume(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Volume> predicate);
  public A withVolumes(java.util.List<io.fabric8.kubernetes.api.model.Volume> volumes);
  public A withVolumes(io.fabric8.kubernetes.api.model.Volume... volumes);
  public java.lang.Boolean hasVolumes();
  public interface ResourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ResourceRequirementsFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<N>>{
    public N and();
    public N endResources();
    
  }
  public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> openshift-model-operatorhub-5.12.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionConfigFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.ResourceRequirementsBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluent;
import io.fabric8.kubernetes.api.model.EnvVar;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.EnvFromSource;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.VolumeMount;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

 /**
  * Generated
  */
public interface SubscriptionConfigFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A setToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A addToEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToEnv(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public A removeFromEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromEnv(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public java.util.List<io.fabric8.kubernetes.api.model.EnvVar> getEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getEnv(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.EnvVar getFirstEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getLastEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public java.lang.Boolean hasMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public A withEnv(java.util.List<io.fabric8.kubernetes.api.model.EnvVar> env);
  public A withEnv(io.fabric8.kubernetes.api.model.EnvVar... env);
  public java.lang.Boolean hasEnv();
  public A addToEnvFrom(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvFromSource item);
  public A setToEnvFrom(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvFromSource item);
  public A addToEnvFrom(io.fabric8.kubernetes.api.model.EnvFromSource... items);
  public A addAllToEnvFrom(java.util.Collection<io.fabric8.kubernetes.api.model.EnvFromSource> items);
  public A removeFromEnvFrom(io.fabric8.kubernetes.api.model.EnvFromSource... items);
  public A removeAllFromEnvFrom(java.util.Collection<io.fabric8.kubernetes.api.model.EnvFromSource> items);
  public java.util.List<io.fabric8.kubernetes.api.model.EnvFromSource> getEnvFrom();
  public io.fabric8.kubernetes.api.model.EnvFromSource getEnvFrom(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.EnvFromSource getFirstEnvFrom();
  public io.fabric8.kubernetes.api.model.EnvFromSource getLastEnvFrom();
  public io.fabric8.kubernetes.api.model.EnvFromSource getMatchingEnvFrom(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvFromSource> predicate);
  public java.lang.Boolean hasMatchingEnvFrom(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvFromSource> predicate);
  public A withEnvFrom(java.util.List<io.fabric8.kubernetes.api.model.EnvFromSource> envFrom);
  public A withEnvFrom(io.fabric8.kubernetes.api.model.EnvFromSource... envFrom);
  public java.lang.Boolean hasEnvFrom();
  public A addToNodeSelector(java.lang.String key,java.lang.String value);
  public A addToNodeSelector(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromNodeSelector(java.lang.String key);
  public A removeFromNodeSelector(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getNodeSelector();
  public <K,V>A withNodeSelector(java.util.Map<java.lang.String,java.lang.String> nodeSelector);
  public java.lang.Boolean hasNodeSelector();
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ResourceRequirements getResources();
  public io.fabric8.kubernetes.api.model.ResourceRequirements buildResources();
  public A withResources(io.fabric8.kubernetes.api.model.ResourceRequirements resources);
  public java.lang.Boolean hasResources();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> withNewResources();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> withNewResourcesLike(io.fabric8.kubernetes.api.model.ResourceRequirements item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> editResources();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> editOrNewResources();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<A> editOrNewResourcesLike(io.fabric8.kubernetes.api.model.ResourceRequirements item);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector();
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector);
  public java.lang.Boolean hasSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> withNewSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> editSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> editOrNewSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public A addToTolerations(java.lang.Integer index,io.fabric8.kubernetes.api.model.Toleration item);
  public A setToTolerations(java.lang.Integer index,io.fabric8.kubernetes.api.model.Toleration item);
  public A addToTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A addAllToTolerations(java.util.Collection<io.fabric8.kubernetes.api.model.Toleration> items);
  public A removeFromTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A removeAllFromTolerations(java.util.Collection<io.fabric8.kubernetes.api.model.Toleration> items);
  public java.util.List<io.fabric8.kubernetes.api.model.Toleration> getTolerations();
  public io.fabric8.kubernetes.api.model.Toleration getToleration(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.Toleration getFirstToleration();
  public io.fabric8.kubernetes.api.model.Toleration getLastToleration();
  public io.fabric8.kubernetes.api.model.Toleration getMatchingToleration(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Toleration> predicate);
  public java.lang.Boolean hasMatchingToleration(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Toleration> predicate);
  public A withTolerations(java.util.List<io.fabric8.kubernetes.api.model.Toleration> tolerations);
  public A withTolerations(io.fabric8.kubernetes.api.model.Toleration... tolerations);
  public java.lang.Boolean hasTolerations();
  public A addNewToleration(java.lang.String effect,java.lang.String key,java.lang.String operator,java.lang.Long tolerationSeconds,java.lang.String value);
  public A addToVolumeMounts(java.lang.Integer index,io.fabric8.kubernetes.api.model.VolumeMount item);
  public A setToVolumeMounts(java.lang.Integer index,io.fabric8.kubernetes.api.model.VolumeMount item);
  public A addToVolumeMounts(io.fabric8.kubernetes.api.model.VolumeMount... items);
  public A addAllToVolumeMounts(java.util.Collection<io.fabric8.kubernetes.api.model.VolumeMount> items);
  public A removeFromVolumeMounts(io.fabric8.kubernetes.api.model.VolumeMount... items);
  public A removeAllFromVolumeMounts(java.util.Collection<io.fabric8.kubernetes.api.model.VolumeMount> items);
  public java.util.List<io.fabric8.kubernetes.api.model.VolumeMount> getVolumeMounts();
  public io.fabric8.kubernetes.api.model.VolumeMount getVolumeMount(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.VolumeMount getFirstVolumeMount();
  public io.fabric8.kubernetes.api.model.VolumeMount getLastVolumeMount();
  public io.fabric8.kubernetes.api.model.VolumeMount getMatchingVolumeMount(java.util.function.Predicate<io.fabric8.kubernetes.api.model.VolumeMount> predicate);
  public java.lang.Boolean hasMatchingVolumeMount(java.util.function.Predicate<io.fabric8.kubernetes.api.model.VolumeMount> predicate);
  public A withVolumeMounts(java.util.List<io.fabric8.kubernetes.api.model.VolumeMount> volumeMounts);
  public A withVolumeMounts(io.fabric8.kubernetes.api.model.VolumeMount... volumeMounts);
  public java.lang.Boolean hasVolumeMounts();
  public A addToVolumes(java.lang.Integer index,io.fabric8.kubernetes.api.model.Volume item);
  public A setToVolumes(java.lang.Integer index,io.fabric8.kubernetes.api.model.Volume item);
  public A addToVolumes(io.fabric8.kubernetes.api.model.Volume... items);
  public A addAllToVolumes(java.util.Collection<io.fabric8.kubernetes.api.model.Volume> items);
  public A removeFromVolumes(io.fabric8.kubernetes.api.model.Volume... items);
  public A removeAllFromVolumes(java.util.Collection<io.fabric8.kubernetes.api.model.Volume> items);
  public java.util.List<io.fabric8.kubernetes.api.model.Volume> getVolumes();
  public io.fabric8.kubernetes.api.model.Volume getVolume(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.Volume getFirstVolume();
  public io.fabric8.kubernetes.api.model.Volume getLastVolume();
  public io.fabric8.kubernetes.api.model.Volume getMatchingVolume(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Volume> predicate);
  public java.lang.Boolean hasMatchingVolume(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Volume> predicate);
  public A withVolumes(java.util.List<io.fabric8.kubernetes.api.model.Volume> volumes);
  public A withVolumes(io.fabric8.kubernetes.api.model.Volume... volumes);
  public java.lang.Boolean hasVolumes();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ResourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ResourceRequirementsFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.ResourcesNested<N>>{
    public N and();
    public N endResources();
    
  }
  public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionConfigFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
